Index: channels/chan_unistim.c
===================================================================
--- channels/chan_unistim.c	(revision 89403)
+++ channels/chan_unistim.c	(working copy)
@@ -78,6 +78,7 @@
 #include "asterisk/stringfields.h"
 #include "asterisk/abstract_jb.h"
 #include "asterisk/event.h"
+#include "asterisk/localtime.h"
 
 /*! Beware, G729 and G723 are not supported by asterisk, except with the proper licence */
 #define CAPABILITY AST_FORMAT_ALAW | AST_FORMAT_ULAW    /* | AST_FORMAT_G729A | AST_FORMAT_G723_1 */
@@ -728,29 +729,27 @@
 
 static void get_localtime(struct systemtime * systime)
 {
-	struct tm *stm;
-	time_t cur_time;
-	
-	time(&cur_time);
+	struct ast_tm stm;
+	struct timeval tv = ast_tvnow();
 
-	if ((stm = localtime(&cur_time)) == 0) {
+	if (ast_localtime(&tv,&stm,NULL) == 0) {
 		display_last_error("Error in localtime()");
 		return;
 	}
 
-	systime->w_year = stm->tm_year;
-	systime->w_month = stm->tm_mon + 1;
-	systime->w_day_of_week = stm->tm_wday;
-	systime->w_day = stm->tm_mday;
-	systime->w_hour = stm->tm_hour;
-	systime->w_minute = stm->tm_min;
-	systime->w_second = stm->tm_sec;
+	systime->w_year = stm.tm_year;
+	systime->w_month = stm.tm_mon + 1;
+	systime->w_day_of_week = stm.tm_wday;
+	systime->w_day = stm.tm_mday;
+	systime->w_hour = stm.tm_hour;
+	systime->w_minute = stm.tm_min;
+	systime->w_second = stm.tm_sec;
 	systime->w_milliseconds = 0;
 }
 
 static unsigned int get_tick_count(void)
 {
-	struct timeval tv = ast_tvnow();;
+	struct timeval tv = ast_tvnow();
 
 	return (tv.tv_sec * 1000) + (tv.tv_usec / 1000);
 }
@@ -778,7 +777,7 @@
 	msg.msg_flags = 0;		      /* flags on received message */
 
 	ip_msg->cmsg_len = CMSG_LEN(sizeof(*pki));
-	ip_msg->cmsg_level = SOL_IP;
+	ip_msg->cmsg_level = IPPROTO_IP;
 	ip_msg->cmsg_type = IP_PKTINFO;
 	pki->ipi_ifindex = 0;	   /* Interface index, 0 = use interface specified in routing table */
 	pki->ipi_spec_dst.s_addr = addr_ourip->sin_addr.s_addr; /* Local address */
@@ -5306,21 +5305,21 @@
 	if (ast_strlen_zero(d->maintext1))
 		strcpy(d->maintext1, d->name);
 	if (ast_strlen_zero(d->titledefault)) {
-		struct tm *stm;
-		time_t cur_time = time(0);
+		struct ast_tm tm;
+		struct timeval cur_time = ast_tvnow();
 
-		if ((stm = localtime(&cur_time)) == 0) {
+		if ((ast_localtime(&cur_time, &tm, 0)) == 0) {
 			display_last_error("Error in localtime()");
 			ast_copy_string(d->titledefault, "UNISTIM for*", 12);
 		} else {
-			if (strlen(stm->tm_zone) < 4) {
+			if (strlen(tm.tm_zone) < 4) {
 				strcpy(d->titledefault, "TimeZone ");
-				strcat(d->titledefault, stm->tm_zone);
-			} else if (strlen(stm->tm_zone) < 9) {
+				strcat(d->titledefault, tm.tm_zone);
+			} else if (strlen(tm.tm_zone) < 9) {
 				strcpy(d->titledefault, "TZ ");
-				strcat(d->titledefault, stm->tm_zone);
+				strcat(d->titledefault, tm.tm_zone);
 			} else
-				ast_copy_string(d->titledefault, stm->tm_zone, 12);
+				ast_copy_string(d->titledefault, tm.tm_zone, 12);
 		}
 	}
 	/* Update the chained link if it's a new device */
Index: Makefile
===================================================================
--- Makefile	(revision 89403)
+++ Makefile	(working copy)
@@ -71,7 +71,7 @@
 
 # Some build systems, such as the one in openwrt, like to pass custom target
 # CFLAGS and LDFLAGS in the COPTS and LDOPTS variables.
-ASTCFLAGS+=$(COPTS)
+ASTCFLAGS+=$(COPTS) -D_XPG4_2
 ASTLDFLAGS+=$(LDOPTS)
 
 #Uncomment this to see all build commands instead of 'quiet' output
Index: codecs/ilbc/iLBC_define.h
===================================================================
--- codecs/ilbc/iLBC_define.h	(revision 89403)
+++ codecs/ilbc/iLBC_define.h	(working copy)
@@ -16,7 +16,6 @@
 
 /* general codec settings */
 
-#define FS                      (float)8000.0
 #define BLOCKL_20MS             160
 #define BLOCKL_30MS             240
 #define BLOCKL_MAX              240
